@@ -81,14 +81,14 @@ def _ssh_key_from_debug_keystore(keystore=KEYSTORE_FILE):
     with open(ssh_private_key_file + '.pub', 'w') as fp:
         fp.write(pub)
 
-    logging.info(_('\nSSH Public Key to be used as Deploy Key:') + '\n' + pub)
+    logging.info(_('\nSSH public key to be used as deploy key:') + '\n' + pub)
 
     return ssh_private_key_file
 
 
 def main():
 
-    parser = ArgumentParser(usage="%(prog)s")
+    parser = ArgumentParser()
     common.setup_global_opts(parser)
     parser.add_argument("--keystore", default=KEYSTORE_FILE,
                         help=_("Specify which debug keystore file to use."))
@@ -170,6 +170,7 @@ def main():
         git_mirror_path = os.path.join(repo_basedir, 'git-mirror')
         git_mirror_repodir = os.path.join(git_mirror_path, 'fdroid', 'repo')
         git_mirror_metadatadir = os.path.join(git_mirror_path, 'fdroid', 'metadata')
+        git_mirror_statsdir = os.path.join(git_mirror_path, 'fdroid', 'stats')
         if not os.path.isdir(git_mirror_repodir):
             logging.debug(_('cloning {url}').format(url=clone_url))
             try:
@@ -191,7 +192,7 @@ def main():
         readme = '''
 # {repo_git_base}
 
-[![{repo_url}](icon.png)]({repo_url})
+[![{repo_url}]({repo_url}/icons/icon.png)]({repo_url})
 
 Last updated: {date}'''.format(repo_git_base=repo_git_base,
                                repo_url=repo_url,
@@ -201,22 +202,16 @@ Last updated: {date}'''.format(repo_git_base=repo_git_base,
         mirror_git_repo.git.add(all=True)
         mirror_git_repo.index.commit("update README")
 
-        icon_path = os.path.join(git_mirror_path, 'icon.png')
-        try:
-            import qrcode
-            qrcode.make(repo_url).save(icon_path)
-        except Exception:
-            exampleicon = os.path.join(common.get_examples_dir(), 'fdroid-icon.png')
-            shutil.copy(exampleicon, icon_path)
         mirror_git_repo.git.add(all=True)
         mirror_git_repo.index.commit("update repo/website icon")
-        shutil.copy(icon_path, repo_basedir)
 
         os.chdir(repo_basedir)
         if os.path.isdir(git_mirror_repodir):
             common.local_rsync(options, git_mirror_repodir + '/', 'repo/')
         if os.path.isdir(git_mirror_metadatadir):
             common.local_rsync(options, git_mirror_metadatadir + '/', 'metadata/')
+        if os.path.isdir(git_mirror_statsdir):
+            common.local_rsync(options, git_mirror_statsdir + '/', 'stats/')
 
         ssh_private_key_file = _ssh_key_from_debug_keystore()
         # this is needed for GitPython to find the SSH key
@@ -231,11 +226,9 @@ Last updated: {date}'''.format(repo_git_base=repo_git_base,
         config += "identity_file = '%s'\n" % ssh_private_key_file
         config += "repo_name = '%s'\n" % repo_git_base
         config += "repo_url = '%s'\n" % repo_url
-        config += "repo_icon = 'icon.png'\n"
         config += "repo_description = 'Nightly builds from %s'\n" % git_user_email
         config += "archive_name = '%s'\n" % (repo_git_base + ' archive')
         config += "archive_url = '%s'\n" % (repo_base + '/archive')
-        config += "archive_icon = 'icon.png'\n"
         config += "archive_description = 'Old nightly builds that have been archived.'\n"
         config += "archive_older = %i\n" % options.archive_older
         config += "servergitmirrors = '%s'\n" % servergitmirror
@@ -245,8 +238,7 @@ Last updated: {date}'''.format(repo_git_base=repo_git_base,
         config += "keypass = '%s'\n" % PASSWORD
         config += "keydname = '%s'\n" % DISTINGUISHED_NAME
         config += "make_current_version_link = False\n"
-        config += "accepted_formats = ('txt', 'yml')\n"
-        # TODO add update_stats = True
+        config += "update_stats = True\n"
         with open('config.py', 'w') as fp:
             fp.write(config)
         os.chmod('config.py', 0o600)
@@ -254,23 +246,23 @@ Last updated: {date}'''.format(repo_git_base=repo_git_base,
         common.assert_config_keystore(config)
 
         for root, dirs, files in os.walk(cibase):
-            for d in ('fdroid', '.git', '.gradle'):
-                if d in dirs:
+            for d in dirs:
+                if d == '.git' or d == '.gradle' or (d == 'fdroid' and root == cibase):
                     dirs.remove(d)
             for f in files:
                 if f.endswith('-debug.apk'):
                     apkfilename = os.path.join(root, f)
-                    logging.debug(_('Striping mystery signature from {apkfilename}')
+                    logging.debug(_('Stripping mystery signature from {apkfilename}')
                                   .format(apkfilename=apkfilename))
                     destapk = os.path.join(repodir, os.path.basename(f))
                     os.chmod(apkfilename, 0o644)
                     logging.debug(_('Resigning {apkfilename} with provided debug.keystore')
                                   .format(apkfilename=os.path.basename(apkfilename)))
-                    common.apk_strip_signatures(apkfilename, strip_manifest=True)
+                    common.apk_strip_v1_signatures(apkfilename, strip_manifest=True)
                     common.sign_apk(apkfilename, destapk, KEY_ALIAS)
 
         if options.verbose:
-            logging.debug(_('attempting bare ssh connection to test deploy key:'))
+            logging.debug(_('attempting bare SSH connection to test deploy key:'))
             try:
                 subprocess.check_call(['ssh', '-Tvi', ssh_private_key_file,
                                        '-oIdentitiesOnly=yes', '-oStrictHostKeyChecking=no',
@@ -293,12 +285,13 @@ Last updated: {date}'''.format(repo_git_base=repo_git_base,
         subprocess.check_call(['fdroid', 'update', '--rename-apks', '--create-metadata', '--verbose'],
                               cwd=repo_basedir)
         common.local_rsync(options, repo_basedir + '/metadata/', git_mirror_metadatadir + '/')
+        common.local_rsync(options, repo_basedir + '/stats/', git_mirror_statsdir + '/')
         mirror_git_repo.git.add(all=True)
         mirror_git_repo.index.commit("update app metadata")
 
         if not options.no_deploy:
             try:
-                cmd = ['fdroid', 'server', 'update', '--verbose', '--no-keep-git-mirror-archive']
+                cmd = ['fdroid', 'deploy', '--verbose', '--no-keep-git-mirror-archive']
                 subprocess.check_call(cmd, cwd=repo_basedir)
             except subprocess.CalledProcessError:
                 logging.error(_('cannot publish update, did you set the deploy key?')
